/*
The software in this package is distributed under the GNU General
Public License version 2 (with a special exception described below).

A copy of GNU General Public License (GPL) is included in this distribution,
in the file COPYING.GPL.

As a special exception, if other files instantiate templates or use macros
or inline functions from this file, or you compile this file and link it
with other works to produce a work based on this file, this file
does not by itself cause the resulting work to be covered
by the GNU General Public License.

However the source code for this file must still be made available
in accordance with section (3) of the GNU General Public License.

This exception does not invalidate any other reasons why a work based
on this file might be covered by the GNU General Public License.
*/

#ifndef PSEUDO_IPV4_HEADER_H
#define PSEUDO_IPV4_HEADER_H

//-----------------------------------------------------------------------------
// PseudoIpv4Header
//-----------------------------------------------------------------------------

/**
 * @brief This class represents a Pseudo IP header used to compute checksum of
 * transport layer protocols.
 *
 * When TCP runs over IPv4, the method used to compute the checksum is defined
 * in RFC 793.
 *
 * Pseudo IPv4 header format used by TCP and UDP checksums:
 *
 * @code
 * 0               8               16                             31
 * +--------------------------------------------------------------+      ---
 * |                                                              |       ^
 * |                      source IPv4 address                     |       |
 * |                                                              |       |
 * +--------------------------------------------------------------+       |
 * |                                                              |       |
 * |                   destination IPv4 address                   |   12 bytes
 * |                                                              |       |
 * +---------------+---------------+------------------------------+       |
 * |               |               |                              |       |
 * |      zero     |   protocol    |        header length         |       |
 * |               |               |                              |       v
 * +---------------+---------------+------------------------------+      ---
 * @endcode
 */
class PseudoIpv4Header
{
public:
    /// Source IPv4 address
    uint8_t source_address[4];
    /// Destination IPv4 address
    uint8_t destination_address[4];
    /// Zero
    uint8_t zero_byte;
    /// Transport layer protocol
    uint8_t protocol;
    /// TCP or UDP header length
    uint16_t header_length;
};

#endif // PSEUDO_IPV4_HEADER_H
